@@ -79,6 +79,8 @@ __all__ = (
     "DatasetTriggerTypeDef",
     "DatasetTypeDef",
     "DatastoreActivityTypeDef",
+    "DatastoreIotSiteWiseMultiLayerStorageSummaryTypeDef",
+    "DatastoreIotSiteWiseMultiLayerStorageTypeDef",
     "DatastorePartitionTypeDef",
     "DatastorePartitionsTypeDef",
     "DatastoreStatisticsTypeDef",
@@ -111,6 +113,8 @@ __all__ = (
     "GetDatasetContentResponseTypeDef",
     "GlueConfigurationTypeDef",
     "IotEventsDestinationConfigurationTypeDef",
+    "IotSiteWiseCustomerManagedDatastoreS3StorageSummaryTypeDef",
+    "IotSiteWiseCustomerManagedDatastoreS3StorageTypeDef",
     "LambdaActivityTypeDef",
     "LateDataRuleConfigurationTypeDef",
     "LateDataRuleTypeDef",
@@ -701,6 +705,21 @@ DatastoreActivityTypeDef = TypedDict(
     },
 )
 
+DatastoreIotSiteWiseMultiLayerStorageSummaryTypeDef = TypedDict(
+    "DatastoreIotSiteWiseMultiLayerStorageSummaryTypeDef",
+    {
+        "customerManagedS3Storage": "IotSiteWiseCustomerManagedDatastoreS3StorageSummaryTypeDef",
+    },
+    total=False,
+)
+
+DatastoreIotSiteWiseMultiLayerStorageTypeDef = TypedDict(
+    "DatastoreIotSiteWiseMultiLayerStorageTypeDef",
+    {
+        "customerManagedS3Storage": "IotSiteWiseCustomerManagedDatastoreS3StorageTypeDef",
+    },
+)
+
 DatastorePartitionTypeDef = TypedDict(
     "DatastorePartitionTypeDef",
     {
@@ -731,6 +750,7 @@ DatastoreStorageSummaryTypeDef = TypedDict(
     {
         "serviceManagedS3": Dict[str, Any],
         "customerManagedS3": "CustomerManagedDatastoreS3StorageSummaryTypeDef",
+        "iotSiteWiseMultiLayerStorage": "DatastoreIotSiteWiseMultiLayerStorageSummaryTypeDef",
     },
     total=False,
 )
@@ -740,6 +760,7 @@ DatastoreStorageTypeDef = TypedDict(
     {
         "serviceManagedS3": Dict[str, Any],
         "customerManagedS3": "CustomerManagedDatastoreS3StorageTypeDef",
+        "iotSiteWiseMultiLayerStorage": "DatastoreIotSiteWiseMultiLayerStorageTypeDef",
     },
     total=False,
 )
@@ -1072,6 +1093,37 @@ IotEventsDestinationConfigurationTypeDef = TypedDict(
     },
 )
 
+IotSiteWiseCustomerManagedDatastoreS3StorageSummaryTypeDef = TypedDict(
+    "IotSiteWiseCustomerManagedDatastoreS3StorageSummaryTypeDef",
+    {
+        "bucket": str,
+        "keyPrefix": str,
+    },
+    total=False,
+)
+
+_RequiredIotSiteWiseCustomerManagedDatastoreS3StorageTypeDef = TypedDict(
+    "_RequiredIotSiteWiseCustomerManagedDatastoreS3StorageTypeDef",
+    {
+        "bucket": str,
+    },
+)
+_OptionalIotSiteWiseCustomerManagedDatastoreS3StorageTypeDef = TypedDict(
+    "_OptionalIotSiteWiseCustomerManagedDatastoreS3StorageTypeDef",
+    {
+        "keyPrefix": str,
+    },
+    total=False,
+)
+
+
+class IotSiteWiseCustomerManagedDatastoreS3StorageTypeDef(
+    _RequiredIotSiteWiseCustomerManagedDatastoreS3StorageTypeDef,
+    _OptionalIotSiteWiseCustomerManagedDatastoreS3StorageTypeDef,
+):
+    pass
+
+
 _RequiredLambdaActivityTypeDef = TypedDict(
     "_RequiredLambdaActivityTypeDef",
     {
